PyXMake Developer Guide: D:/03_Workspaces/01_Eclipse/pyx_core/PyXMake/__init__.py Source File

| PyXMake Developer Guide 1.0 PyXMake

D:/03_Workspaces/01_Eclipse/pyx_core/PyXMake/__init__.py
1 # %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
2 # PyXMake %
3 # %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
4 """
5 PyXMake is a cross-plattform build tool for source files using either Intel Fortran,
6 Py2X, a SSH connection or Doxygen to build a library or to automatically create a
7 documentation.
8
9 @note: PyXMake.__init__()
10 Created on 20.03.2018
11
12 @version: 1.0
13 ----------------------------------------------------------------------------------------------
14 @requires:
15 -
16
17 @change:
18 -
19
20 @contributors:
21 Falk Heinecke
22 Sebastian Freund
23 Andreas Schuster
24
25 @author: garb_ma [DLR-FA,STM Braunschweig]
26 ----------------------------------------------------------------------------------------------
27 """
28
29 ## @package PyXMake
30 # PyXMake package for programmable build events on Linux and Windows.
31 ## @authors
32 # Marc Garbade,
33 # Falk Heinecke,
34 # Sebastian Freund,
35 # Andreas Schuster
36 ## @date
37 # 20.03.2018
38 ## @par Notes/Changes
39 # - Added documentation // mg 29.03.2018
40
41 import os
42 ## Absolute system path to PyXMake.
43 PyXMakePath = os.path.dirname(os.path.abspath(__file__))
44
45 if __name__ == '__main__':
46 pass